ARIS-lite: Plant Drought and Heat Stress Model
==============================================

Overview
--------

ARIS-lite is a Python framework designed to compute plant stress
indicators from modeling the soil water balance using meteorological
input data. The package provides tools for:

- Processing meteorological input data
- Modeling soil water balance
- Calculating various plant stress indicators

Key Features
------------

- Modular architecture for easy extension
- Extensible for different plant types and environments

Key limitations
---------------

- Strict requirements, e.g., on the format of input data
- Limited set of crops and stress indicators

Getting Started
---------------

To learn more about using ARIS-lite, please refer to the following sections:

.. toctree::
   :maxdepth: 1

   installation
   usage

For detailed technical documentation, see the API documentation:

.. toctree::
   :maxdepth: 1

   aris_lite
